/*
  WiFi Web Server LED Blink

 A simple web server that lets you blink an LED via the web.
 This sketch will print the IP address of your WiFi Shield (once connected)
 to the Serial monitor. From there, you can open that address in a web browser
 to turn on and off the LED on pin 9.

 If the IP address of your shield is yourAddress:
 http://yourAddress/H turns the LED on
 http://yourAddress/L turns it off

 This example is written for a network using WPA encryption. For
 WEP or WPA, change the WiFi.begin() call accordingly.

 Circuit:
 * WiFi shield attached
 * LED attached to pin 9

 created 25 Nov 2012
 by Tom Igoe
 */
#include <SPI.h>
#include <WiFi101.h>

#include "arduino_secrets.h"
///////please enter your sensitive data in the Secret tab/arduino_secrets.h
char ssid[] = SECRET_SSID;        // your network SSID (name)
char pass[] = SECRET_PASS;    // your network password (use for WPA, or use as key for WEP)
int keyIndex = 0;                 // your network key Index number (needed only for WEP)

int status = WL_IDLE_STATUS;
WiFiServer server(80);

/* Silahkan isi global variable atau constant dibawah ini*/
const int DigIn0 = 0;
const int DigIn1 = 1;
const int DigIn2 = 2;
const int DigIn3 = 3;
 
const int DigOut0 = 4;
const int DigOut1 = 5;
const int DigOut2 = 6;
const int DigOut3 = 7;

int sensorValue0 = 0;  
int sensorValue1 = 0;  
int sensorValue2 = 0;  
int sensorValue3 = 0;  
int sensorValue4 = 0;  
int sensorValue5 = 0;
int sensorValue6 = 0;
    
float Ain0_Voltage;
float Ain1_Voltage;
float Ain2_Voltage;
float Ain3_Voltage;
float Ain4_Voltage;
float Ain5_Voltage;
float Ain6_Voltage;

float Room_Temperature;


void setup() {
  Serial.begin(9600);      // initialize serial communication
  // Dibawah ini adalah setup untuk I/O silahkan awali dengan 2x haris miring (//) jika setup tidak dipakai
  analogReadResolution(12);
  pinMode(DigIn0, INPUT);
  pinMode(DigIn1, INPUT);
  pinMode(DigIn2, INPUT);
  pinMode(DigIn3, INPUT);
  pinMode(DigOut0, OUTPUT);
  pinMode(DigOut1, OUTPUT);
  pinMode(DigOut2, OUTPUT);
  pinMode(DigOut3, OUTPUT);

  //Dibawah ini adalah setup program untuk Wifi, untuk mempermudah biarkan seperti apa adanya, 
  // check for the presence of the shield:
  if (WiFi.status() == WL_NO_SHIELD) {
    Serial.println("WiFi shield not present");
    while (true);       // don't continue
  }

  // attempt to connect to WiFi network:
  while ( status != WL_CONNECTED) {
    Serial.print("Attempting to connect to Network named: ");
    Serial.println(ssid);                   // print the network name (SSID);

    // Connect to WPA/WPA2 network. Change this line if using open or WEP network:
    status = WiFi.begin(ssid, pass);
    // wait 10 seconds for connection:
    delay(10000);
  }
  printWiFiStatus();                        // you're connected now, so print out the status
  server.begin();                           // start the web server on port 80
}


void loop() {
  // Dibawah ini adalah program template untuk Analog input
  sensorValue0 = analogRead(A0);
  sensorValue1 = analogRead(A1);
  sensorValue2 = analogRead(A2);
  sensorValue3 = analogRead(A3);
  sensorValue4 = analogRead(A4);
  sensorValue5 = analogRead(A5);
  sensorValue6 = analogRead(A6);
  Ain0_Voltage = calcAin_Voltage(sensorValue0);
  Ain1_Voltage = calcAin_Voltage(sensorValue1);
  Ain2_Voltage = calcAin_Voltage(sensorValue2);
  Ain3_Voltage = calcAin_Voltage(sensorValue3);
  Ain4_Voltage = calcAin_Voltage(sensorValue4);
  Ain5_Voltage = calcAin_Voltage(sensorValue5);
  Ain6_Voltage = calcAin_Voltage(sensorValue6);

  // Silahkan buat Program I/O dibawah ini
 Room_Temperature = (125.0/1.25)*Ain0_Voltage;

  // Silahkan buat Program wifi dibawah ini
  WiFiClient client = server.available();   // listen for incoming clients

  if (client) {                             // if you get a client,
    Serial.println("new client");           // print a message out the serial port
    String currentLine = "";                // make a String to hold incoming data from the client
    while (client.connected()) {            // loop while the client's connected
      if (client.available()) {             // if there's bytes to read from the client,
        char c = client.read();             // read a byte, then
        Serial.write(c);                    // print it out the serial monitor
        if (c == '\n') {                    // if the byte is a newline character

          // if the current line is blank, you got two newline characters in a row.
          // that's the end of the client HTTP request, so send a response:
          if (currentLine.length() == 0) {
            // HTTP headers always start with a response code (e.g. HTTP/1.1 200 OK)
            // and a content-type so the client knows what's coming, then a blank line:
            client.println("HTTP/1.1 200 OK");
            client.println("Content-type:text/html");
            client.println();

            // the content of the HTTP response follows the header:
            client.print("<head>");
            client.print("<meta http-equiv=\"refresh\" content=\"5\">");
            client.print("<title>Arduino Simple Web Server</title>");
            client.print("</head>");
            client.print("<body>");
            client.print("<h1>Arduino Simple Web Server</h1>");
            client.print("<p>Room Temperature:");
            client.print(Room_Temperature);
            client.print(" DegC");
            client.print("</p>");
            client.print("<body>");

            // The HTTP response ends with another blank line:
            client.println();
            // break out of the while loop:
            break;
          }
          else {      // if you got a newline, then clear currentLine:
            currentLine = "";
          }
        }
        else if (c != '\r') {    // if you got anything else but a carriage return character,
          currentLine += c;      // add it to the end of the currentLine
        }
        
      }
    }
    delay(1);
    // close the connection:
    client.stop();
    Serial.println("client disonnected");
  }


  

}

void printWiFiStatus() {
  // print the SSID of the network you're attached to:
  Serial.print("SSID: ");
  Serial.println(WiFi.SSID());

  // print your WiFi shield's IP address:
  IPAddress ip = WiFi.localIP();
  Serial.print("IP Address: ");
  Serial.println(ip);

  // print the received signal strength:
  long rssi = WiFi.RSSI();
  Serial.print("signal strength (RSSI):");
  Serial.print(rssi);
  Serial.println(" dBm");

}

float calcAin_Voltage(int AinValue)
{
  float result;
  result = (5.0/4095.0) * AinValue;
  return result;
}
